--- a/configure.ac
+++ b/configure.ac
@@ -1449,6 +1449,28 @@
 
 AM_CONDITIONAL(KDE4_APPLET, test "x$enable_kde4_applet" = xyes)
 
+dnl ****************************
+dnl *** test for KDE5 applet ***
+dnl ****************************
+AC_ARG_ENABLE(kde5-applet,
+  AC_HELP_STRING([--disable-kde5-applet],
+    [do not build uim KDE Plasma 5 widget]),
+  [],
+  [enable_kde5_applet=yes])
+
+if test "x$enable_kde5_applet" != xno; then
+  if test "x$with_qt5" != xyes; then
+    enable_kde5_applet=no
+  fi
+fi
+
+if test "x$enable_kde5_applet" = xyes && test "x$CMAKE" = xno; then
+  AC_MSG_WARN([no CMake found])
+  enable_kde5_applet=no
+fi
+
+AM_CONDITIONAL(KDE5_APPLET, test "x$enable_kde5_applet" = xyes)
+
 AC_ARG_ENABLE(pref,
   AC_HELP_STRING([--disable-pref],
     [do not build graphical utility to edit user settings]),
@@ -1948,12 +1970,15 @@
     qt5_immodule_option="DEFINES+=QT5_IMMODULE"
   fi
   set -e
-  # FIXME: move CMAKE_CXX_FLAGS into cmake_option
-  ${CMAKE} \
-    -B ${ac_abs_top_builddir}/qt5/applet.cmake \
-    -S ${ac_abs_top_srcdir}/qt5/applet \
-    -DCMAKE_CXX_FLAGS="${CXXFLAGS} ${X_CFLAGS}" \
-    ${cmake_option}
+  # Generate a Makefile for KDE5 applet by cmake
+  if test "x$enable_kde5_applet" = xyes; then
+    # FIXME: move CMAKE_CXX_FLAGS into cmake_option
+    ${CMAKE} \
+      -B ${ac_abs_top_builddir}/qt5/applet.cmake \
+      -S ${ac_abs_top_srcdir}/qt5/applet \
+      -DCMAKE_CXX_FLAGS="${CXXFLAGS} ${X_CFLAGS}" \
+      ${cmake_option}
+  fi
   ${QMAKE5} -o ${ac_abs_top_builddir}/qt5/candwin/Makefile.qmake \
     ${ac_abs_top_builddir}/qt5/candwin/uim-candwin-qt5.pro
   ${QMAKE5} -o ${ac_abs_top_builddir}/qt5/chardict/Makefile.qmake \
@@ -2007,6 +2032,7 @@
    Qt5 immodule    : ${with_qt5_immodule}
    KDE3 Applet     : ${enable_kde_applet}
    KDE4 Applet     : ${enable_kde4_applet}
+   KDE5 Applet     : ${enable_kde5_applet}
    FEP             : ${enable_fep}
    Emacs           : ${enable_emacs}
    XIM             : ${use_xim}
--- a/qt5/applet/Makefile.am
+++ b/qt5/applet/Makefile.am
@@ -6,6 +6,8 @@
 	plasmoid
 
 if QT5
+if KDE5_APPLET
 all clean install uninstall:
 	$(MAKE) $(AM_MAKEFLAGS) -C ../applet.cmake $@
 endif
+endif
